<?php

// Spanish language include
// For version 2.0 PHP iCalendar
//
// Translation by Juan carlos Negron(carich37@hotmail.com)
// Translation by Luis Fernando Rocha (ludwig_von_rocht@yahoo.com)
//

$lang['l_day'] 			= 'D&iacute;a';
$lang['l_week'] 			= 'Semana';
$lang['l_month'] 			= 'Mes';
$lang['l_year'] 			= 'A&ntilde;o';
$lang['l_calendar'] 		= 'Calendario';
$lang['l_next_day'] 		= 'D&iacute;a siguiente';
$lang['l_next_month'] 		= 'Mes siguiente';
$lang['l_next_week'] 		= 'Semana siguiente';
$lang['l_next_year'] 		= 'A&ntilde;o siguiente';
$lang['l_last_day'] 		= 'D&iacute;a anterior';
$lang['l_last_month'] 		= 'Mes anterior';
$lang['l_last_week'] 		= 'Semana anterior';
$lang['l_last_year'] 		= 'A&ntilde;o anterior';
$lang['l_subscribe'] 		= 'Suscribir';
$lang['l_download'] 		= 'Descargar';
$lang['l_powered_by'] 		= 'Operaci&oacute;n por';  // Changed
$lang['l_event'] 			= 'Evento';
$lang['l_event_start'] 		= 'Inicio';
$lang['l_event_end'] 		= 'Fin';
$lang['l_this_months'] 		= 'Eventos de este mes';
$lang['l_date'] 			= 'Fecha';
$lang['l_summary'] 		= 'Descripci&oacute;n';
$lang['l_all_day'] 		= 'todo el d&iacute;a';
$lang['l_notes'] 			= 'Notas';
$lang['l_this_years'] 		= 'Eventos de este a&ntilde;o';
$lang['l_today'] 			= 'Hoy';
$lang['l_this_week'] 		= 'Esta semana';
$lang['l_this_month'] 		= 'Este mes';
$lang['l_jump'] 			= 'Ir a';
$lang['l_tomorrows'] 		= 'Eventos de ma&ntilde;ana';
$lang['l_goday'] 			= 'Ir a Hoy';
$lang['l_goweek'] 			= 'Ir a esta semana';
$lang['l_gomonth'] 			= 'Ir a este Mes';
$lang['l_goyear'] 			= 'Ir a este A&ntilde;o';
$lang['l_search'] 			= 'Buscar'; // the verb
$lang['l_results'] 			= 'Resultados de la b&uacute;squeda';
$lang['l_pick_multiple'] 	= 'Seleccionar multiples';  // Changed
$lang['l_query'] 			= 'Consulta: '; // will be followed by the search query
$lang['l_no_results'] 		= 'Ning&uacute;n evento encontrado';
$lang['l_goprint'] 		= 'Formato de impresi&oacute;n';
$lang['l_time'] 			= 'Hora';
$lang['l_summary'] 		= 'Resumen';
$lang['l_description'] 		= 'Descripci&oacute;n';
$lang['l_this_site_is']		= 'Esta p&aacute;gina es';
$lang['l_no_events_day']	= 'No hay eventos para hoy.';
$lang['l_no_events_week']	= 'No hay eventos para esta semana.';
$lang['l_no_events_month']	= 'No hay eventos para este mes.';
$lang['l_rss_day_date']		= 'g:i A';  // Lists just the time
$lang['l_rss_week_date	']	= '%e de %b';  // Lists just the day
$lang['l_rss_month_date	']	= '%e de %b';  // Lists just the day
$lang['l_rss_language']		= 'es-es';
$lang['l_search_took']		= 'La busqeda tard&oacute; %s segundos';
$lang['l_recurring_event']	= 'Evento peri&ocaute;dico';
$lang['l_exception']		= 'Excepci&oacute;n';
$lang['l_no_query']		= 'falta la consulta';
$lang['l_preferences']		= 'Preferencias';
$lang['l_printer']		= 'Impresora';
$lang['l_select_lang']		= 'Escoja su idioma principal:';  // Changed
$lang['l_select_cal']		= 'Escoja su calendario principal:';  // Changed
$lang['l_select_view']		= 'Elija su vista por defecto:';  // Changed
$lang['l_select_time']		= 'Elija su hora de inicio principal:';  // Changed
$lang['l_select_day']		= 'Escoja d&aacute;a para iniciar semana:';  // Changed
$lang['l_select_style']		= 'Seleccione su estilo principal:';  // Changed
$lang['l_set_prefs']		= 'Guardar preferencias';
$lang['l_completed_date']	= 'Finalizado el';
$lang['l_completed']		= 'Finalizado';
$lang['l_created']			= 'Creado:';
$lang['l_due']				= 'Fecha limite:';
$lang['l_priority']			= 'Prioridad:';
$lang['l_priority_high']	= 'Alta';
$lang['l_priority_low']		= 'Baja';
$lang['l_priority_medium']	= 'Media';
$lang['l_priority_none']	= 'Ninguna';
$lang['l_status']			= 'Estado';
$lang['l_status_confirmed'] = 'CONFIRMADO' ;   // Changed
$lang['l_status_cancelled'] = 'CANCELADO';   // Changed
$lang['l_status_tentative'] = 'PENDIENTE';   // Changed
$lang['l_todo']			= 'Por hacer';
$lang['l_unfinished']		= 'Sin terminar';
$lang['l_prefs_set'] 		= 'Sus preferencias han sido guardadas.';
$lang['l_prefs_unset'] 		= 'Preferencias no activas. Los cambios se activaran al recargar la p&aacute;gina.';
$lang['l_unset_prefs'] 		= 'Preferencias sin activar:';
$lang['l_organizer']		= 'Organizador';
$lang['l_attendee']		= 'Participante';
$lang['l_location']		= 'Lugar';
$lang['l_admin_header']		= 'Administraci&oacute;n de PHP iCalendar';
$lang['l_username']			= 'Usuario';
$lang['l_password']			= 'Contrase&ntilde;a';
$lang['l_login']			= 'Registro';
$lang['l_invalid_login']	= 'Usuario o contrase&ntilde;a incorrectos.';
$lang['l_addupdate_cal']	= 'Agregar o actualizar un calendario';
$lang['l_addupdate_desc']	= 'Agrega un calendario, enviando un archivo nuevo. Actualiza un calendario reemplazandolo con un archivo con el mismo nombre.';
$lang['l_delete_cal']		= 'Borra un calendario';
$lang['l_logout']			= 'Salir';
$lang['l_cal_file']		= 'Archivo de Calendario';
$lang['l_php_error']		= 'Error PHP';
$upload_error_gen_lang		= 'Hubo un problema con su env&iacute;o.';
$upload_error_lang[0]		= 'Hubo un problema con su env&iacute;o.';
$upload_error_lang[1]		= 'El archivo que intenta enviar es demasiado grande.';
$upload_error_lang[2]		= 'El archivo que intenta enviar es demasiado grande.';
$upload_error_lang[3]		= 'Solamente ha recibido una parte del archivo que intentaba enviar.';
$upload_error_lang[4]		= 'Debe elegir un archivo para enviar.';
$lang['l_upload_error_type'] = 'Solo se aceptan archivos de calendario (.ics).';
$lang['l_copy_error']		= 'Fall&oacute; la copia del archivo';
$lang['l_delete_error']		= 'Fall&oacute; el borrado del archivo';
$lang['l_delete_success']	= 'fue borrado exitosamente.';
$lang['l_action_success']	= 'Su acci&oacute;n se realiz&oacute; con &eacute;xito.';
$lang['l_submit']			= 'Enviar';
$lang['l_delete']			= 'Borrar';
$all_cal_comb_lang		= 'Todos los calendarios combinados';

// New for 2.0
$lang['l_legend']			= 'Leyenda';
$lang['l_admin_subhead']	= 'Administra los calendarios desde esta p&aacute;gina';
$lang['l_prefs_subhead']	= 'Establece una cookie por vistar este sitio';
$lang['l_rss_info']			= 'Informaci&oacute;n sobre RSS';
$lang['l_rss_subhead']		= 'Fuentes RSS b&aacute;sicas estan disponibles para cada calendario';
$lang['l_rss_notenabled']	= 'RSS no est&aacute; disponible en este sitio';

// - navigation
$lang['l_back'] 		= 'Atr&aacute;s';
$lang['l_next'] 		= 'Siguiente';
$lang['l_prev'] 		= 'Anterior';
$lang['l_day_view'] 	= 'Vista diaria';
$lang['l_week_view'] 	= 'Vista semanal';
$lang['l_month_view'] 	= 'Vista mensual';
$lang['l_year_view'] 	= 'Vista anual';

// ---------------------------------


// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';							// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('a&ntilde;o','a&ntilde;os');		// for these, put singular
$format_recur_lang['monthly']		= array('mes','meses');					// and plural forms
$format_recur_lang['weekly']		= array('semana','semanas');				// these will be %freq%
$format_recur_lang['daily']		= array('d&iacute;a','dias');				// in the replacement below
$format_recur_lang['hourly']		= array('hora','horas');
$format_recur_lang['minutely']		= array('minuto','minutos');
$format_recur_lang['secondly']		= array('segundo','segundos');

$format_recur_lang['start']			= 'Cada %int% %freq% %for%';		// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= 'hasta %date%';				// ie, 'until January 4'
$format_recur_lang['count']			= 'durante %int% veces';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'En los meses: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= 'En los dias: %list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']		= 'En los dias de la semana: %list%';	// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang			= array ('Domingo','Lunes','Martes','Mi&eacute;rcoles','Jueves','Viernes','S&aacute;bado');
$daysofweekshort_lang		= array ('Dom','Lun','Mar','Mie','Jue','Vie','Sab');
$daysofweekreallyshort_lang	= array ('D','L','M','X','J','V','S');
$monthsofyear_lang		= array ('Enero','Febrero','Marzo','Abril','Mayo','Junio','Julio','Agosto','Septiembre','Octubre','Noviembre','Diciembre');
$monthsofyearshort_lang		= array ('Ene','Feb','Mar','Abr','May','Jun','Jul','Ago','Sep','Oct','Nov','Dic');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'g:i A';
$timeFormat_small = 'g:i';

// For date formatting, see note below
$dateFormat_day = '%A, %e de %B';
$dateFormat_week = '%e de %B';
$dateFormat_week_list = '%a, %e de %b';
$dateFormat_week_jump = '%e de %b';
$dateFormat_month = '%B de %Y';
$dateFormat_month_list = '%A, %e de %B';
$dateFormat_year = '%Y';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= '&iexcl;Error!';
$lang['l_error_window'] 		= '&iexcl;Hubo un error!';
$lang['l_error_calendar'] 		= 'Cuando se produjo este error, se procesaba "%s" del calendario.';
$lang['l_error_path'] 			= 'Incapaz de abrir la ruta a: "%s"';
$lang['l_error_back'] 			= 'Por favor, use el bot&oacute;n "Atr&aacute;s" para volver.';
$lang['l_error_remotecal'] 		= 'Este servidor bloquea calendarios remotos que no han sido aprobados.';
$lang['l_error_restrictedcal'] 	= 'Usted ha intentado accesar un calendario restringido en este servidor.';  // Changed
$lang['l_error_invalidcal'] 		= 'Archivo de calendario inv&aacute;lido. Por favor, pruebe con otro calendario.';
$lang['l_error_cantopen'] 		= 'Incapaz de abrir el calendario.';  // Changed
$lang['l_error_cache']			= 'Incapaz de escribir al directorio de memoria. Verifique su configuraci&oacute;.';  // Changed

?>
